@@ -19,6 +19,7 @@
 #
 
 # Python imports
+import errno
 import os
 import subprocess
 import shutil
@@ -634,8 +635,12 @@ blacklist nouveau
             "app-arch/rpm",
             "app-admin/anaconda",
             "app-admin/authconfig",
-            "app-misc/anaconda-runtime",
-            "app-misc/anaconda-runtime-gui",
+            "app-admin/calamares-sabayon",
+            "app-admin/calamares-sabayon-branding",
+            "app-admin/calamares-sabayon-base-modules",
+            "app-admin/calamares",
+            "dev-libs/libreport",
+            "dev-libs/satyr",
             "dev-python/python-blivet",
             "dev-python/python-meh",
             "dev-util/pykickstart",
@@ -842,3 +847,11 @@ blacklist nouveau
 
         log.info("Backend generated boot cmdline: %s" % (cmdline,))
         self._backend.storage.bootloader.boot_args.update(cmdline)
+
+        # Make sure that /boot/grub is present
+        boot_grub = os.path.join(ROOT_PATH, "boot/grub")
+        try:
+            os.makedirs(boot_grub, 0o755)
+        except OSError as err:
+            if err.errno != errno.EEXIST:
+                raise
